#! /usr/bin/perl
#**********************************************************************
#* (C) Copyright IBM Corporation 2004, 2004.  All rights reserved.    *
#>                                                                    *
#* Tivoli Storage Manager                                             *
#*                                                                    *
#* This script displays the registered nodes that are not currently   *
#* defined as members of a collocation group, and their domain.       *
#*                                                                    *
#* Usage: nongroupednodes -ID=userid -PAssword=password               *
#*                                                                    *
#*        where -ID=userid specifies the administrator's user ID      *
#*              -PAssword=password specifies the administrator's      *
#*                 password                                           *
#*                                                                    *
#* Dependencies: UNIX or Windows                                      *
#*               Perl interpreter installed                           *
#*               TSM administrative client installed and configured   *
#*               TSM 5.3.0 server or higher                           *
#>                                                                    *
#* Note: This sample script is shipped "AS-IS" with all TSM server    *
#* platforms and must remain formatted with lines less than 80        *
#* characters each.                                                   *
#*                                                                    *
#**********************************************************************
use strict;
if ( @ARGV == 0 ) { usage() }

my $Id = "";
my $Pa = "";
while ( substr( $ARGV[0], 0, 1 ) eq "-" ) {
   my $A = uc( $ARGV[0] );
   if ( chkarg( $A, "-ID", 3 ) )       { $Id = $ARGV[0]; shift; next; }
   if ( chkarg( $A, "-PASSWORD", 3 ) ) { $Pa = $ARGV[0]; shift; next; }
   if ( $ARGV[0] eq "-h" ) { usage() }
   print "Syntax error: Argument $ARGV[0] not understood.\n"; shift;
}

if ( $Id eq '' ) {
   print "Syntax error: TSM administrator's user ID must be supplied.\n";
   usage();
   exit;
}
if ( $Pa eq '' ) {
   print "Syntax error: TSM administrator's password must be supplied.\n";
   usage();
   exit;
}
if ( @ARGV > 0 ) {
   print "Syntax error: Extraneous arguments supplied.\n";
   usage();
   exit;
}

open  MACRO, ">_nongrpd.mac" or die;
print MACRO  'select domain_name as "Domain", node_name as';
print MACRO  ' "Nodes not defined to collocation group"';
print MACRO  ' from nodes where collocgroup_name is null';
print MACRO  " order by domain_name, node_name\n";
close MACRO;

system "dsmadmc $Id $Pa -displaymode=table macro _nongrpd.mac";
unlink "_nongrpd.mac";
exit;

sub usage
#**********************************************************************
#* Display program usage information by reading program code header   *
#*                                                                    *
#**********************************************************************
{
   my $Skip = 1;
   open USAGE, "<$0";
   while ( <USAGE> ) {
      if ( substr( $_, 0, 2 ) eq "#>" ) {
         if ( $Skip == 1 ) { $Skip = 0 }
         else              { last }
      }
      if ( $Skip == 0 ) { chop; chop; print substr( $_, 3 )."\n" }
   }
   close USAGE;
   exit 4;
}

sub chkarg
#**********************************************************************
#* Check supplied userid and password arguments                       *
#*                                                                    *
#**********************************************************************
{
   my ( $Arg, $Flag, $Length ) = @_;
   my @Arg = split "=", $Arg;
   if ( length( $Arg[0] ) > $Length ) { $Length = length( $Arg[0] ) }
   if ( $Arg[0] eq substr( $Flag, 0, $Length ) and $Arg[1] ne '' ) {
      return 1;
   }
   else {
      return 0;
   }
}
